@@ -424,10 +424,19 @@ get_job_options(typval_T *tv, jobopt_T *opt, int supported, int supported2)
 	    }
 	    else if (STRCMP(hi->hi_key, "term_rows") == 0)
 	    {
+		int error = FALSE;
+
 		if (!(supported2 & JO2_TERM_ROWS))
 		    break;
 		opt->jo_set2 |= JO2_TERM_ROWS;
-		opt->jo_term_rows = tv_get_number(item);
+		opt->jo_term_rows = tv_get_number_chk(item, &error);
+		if (error)
+		    return FAIL;
+		if (opt->jo_term_rows < 0 || opt->jo_term_rows > 1000)
+		{
+		    semsg(_(e_invargval), "term_rows");
+		    return FAIL;
+		}
 	    }
 	    else if (STRCMP(hi->hi_key, "term_cols") == 0)
 	    {
@@ -559,7 +568,7 @@ get_job_options(typval_T *tv, jobopt_T *opt, int supported, int supported2)
 		    {
 			if (called_emsg_before == called_emsg)
 			    // may not get the error if the GUI didn't start
-			    semsg(_(e_alloc_color), color_name);
+			    semsg(_(e_cannot_allocate_color_str), color_name);
 			return FAIL;
 		    }
 
