@@ -652,11 +652,7 @@ static char *(features[]) =
 #else
 	"-timers",
 #endif
-#ifdef FEAT_TITLE
 	"+title",
-#else
-	"-title",
-#endif
 #ifdef FEAT_TOOLBAR
 	"+toolbar",
 #else
@@ -757,6 +753,324 @@ static char *(features[]) =
 
 static int included_patches[] =
 {   /* Add new patch number below this line */
+/**/
+    3741,
+/**/
+    3740,
+/**/
+    3739,
+/**/
+    3738,
+/**/
+    3737,
+/**/
+    3736,
+/**/
+    3735,
+/**/
+    3734,
+/**/
+    3733,
+/**/
+    3732,
+/**/
+    3731,
+/**/
+    3730,
+/**/
+    3729,
+/**/
+    3728,
+/**/
+    3727,
+/**/
+    3726,
+/**/
+    3725,
+/**/
+    3724,
+/**/
+    3723,
+/**/
+    3722,
+/**/
+    3721,
+/**/
+    3720,
+/**/
+    3719,
+/**/
+    3718,
+/**/
+    3717,
+/**/
+    3716,
+/**/
+    3715,
+/**/
+    3714,
+/**/
+    3713,
+/**/
+    3712,
+/**/
+    3711,
+/**/
+    3710,
+/**/
+    3709,
+/**/
+    3708,
+/**/
+    3707,
+/**/
+    3706,
+/**/
+    3705,
+/**/
+    3704,
+/**/
+    3703,
+/**/
+    3702,
+/**/
+    3701,
+/**/
+    3700,
+/**/
+    3699,
+/**/
+    3698,
+/**/
+    3697,
+/**/
+    3696,
+/**/
+    3695,
+/**/
+    3694,
+/**/
+    3693,
+/**/
+    3692,
+/**/
+    3691,
+/**/
+    3690,
+/**/
+    3689,
+/**/
+    3688,
+/**/
+    3687,
+/**/
+    3686,
+/**/
+    3685,
+/**/
+    3684,
+/**/
+    3683,
+/**/
+    3682,
+/**/
+    3681,
+/**/
+    3680,
+/**/
+    3679,
+/**/
+    3678,
+/**/
+    3677,
+/**/
+    3676,
+/**/
+    3675,
+/**/
+    3674,
+/**/
+    3673,
+/**/
+    3672,
+/**/
+    3671,
+/**/
+    3670,
+/**/
+    3669,
+/**/
+    3668,
+/**/
+    3667,
+/**/
+    3666,
+/**/
+    3665,
+/**/
+    3664,
+/**/
+    3663,
+/**/
+    3662,
+/**/
+    3661,
+/**/
+    3660,
+/**/
+    3659,
+/**/
+    3658,
+/**/
+    3657,
+/**/
+    3656,
+/**/
+    3655,
+/**/
+    3654,
+/**/
+    3653,
+/**/
+    3652,
+/**/
+    3651,
+/**/
+    3650,
+/**/
+    3649,
+/**/
+    3648,
+/**/
+    3647,
+/**/
+    3646,
+/**/
+    3645,
+/**/
+    3644,
+/**/
+    3643,
+/**/
+    3642,
+/**/
+    3641,
+/**/
+    3640,
+/**/
+    3639,
+/**/
+    3638,
+/**/
+    3637,
+/**/
+    3636,
+/**/
+    3635,
+/**/
+    3634,
+/**/
+    3633,
+/**/
+    3632,
+/**/
+    3631,
+/**/
+    3630,
+/**/
+    3629,
+/**/
+    3628,
+/**/
+    3627,
+/**/
+    3626,
+/**/
+    3625,
+/**/
+    3624,
+/**/
+    3623,
+/**/
+    3622,
+/**/
+    3621,
+/**/
+    3620,
+/**/
+    3619,
+/**/
+    3618,
+/**/
+    3617,
+/**/
+    3616,
+/**/
+    3615,
+/**/
+    3614,
+/**/
+    3613,
+/**/
+    3612,
+/**/
+    3611,
+/**/
+    3610,
+/**/
+    3609,
+/**/
+    3608,
+/**/
+    3607,
+/**/
+    3606,
+/**/
+    3605,
+/**/
+    3604,
+/**/
+    3603,
+/**/
+    3602,
+/**/
+    3601,
+/**/
+    3600,
+/**/
+    3599,
+/**/
+    3598,
+/**/
+    3597,
+/**/
+    3596,
+/**/
+    3595,
+/**/
+    3594,
+/**/
+    3593,
+/**/
+    3592,
+/**/
+    3591,
+/**/
+    3590,
+/**/
+    3589,
+/**/
+    3588,
+/**/
+    3587,
+/**/
+    3586,
+/**/
+    3585,
+/**/
+    3584,
+/**/
+    3583,
 /**/
     3582,
 /**/
